@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: HUnit
-version: 1.2.4.2
-id: HUnit-1.2.4.2-be0344577c1a02dafa135a046cdc2b0a
+version: 1.2.5.1
+id: HUnit-1.2.5.1-04fafbcfa793ac20134c5b9972485d17
 
 license: BSD3
 copyright:
@@ -9,6 +9,7 @@ maintainer: hunit@richardg.name
 stability: stable
 homepage: http://hunit.sourceforge.net/
 package-url:
+synopsis: A unit testing framework for Haskell
 description: HUnit is a unit testing framework for Haskell, inspired by the
              JUnit tool for Java, see: <http://www.junit.org>.
 category: Testing
@@ -18,19 +19,21 @@ exposed: True
 exposed-modules: Test.HUnit.Base Test.HUnit.Lang
                  Test.HUnit.Terminal Test.HUnit.Text Test.HUnit
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/HUnit-1.2.4.2
-library-dirs: /usr/local/lib/ghc/HUnit-1.2.4.2
-hs-libraries: HSHUnit-1.2.4.2
+trusted: False
+import-dirs: /usr/local/lib/ghc/HUnit-1.2.5.1
+library-dirs: /usr/local/lib/ghc/HUnit-1.2.5.1
+hs-libraries: HSHUnit-1.2.5.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
+depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
+         deepseq-1.3.0.0-c8a9e8b538aecb7581533b9c1d19faed
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-HUnit-1.2.4.2/html/HUnit.haddock
-haddock-html: /usr/local/share/doc/hs-HUnit-1.2.4.2/html
+haddock-interfaces: /usr/local/share/doc/hs-HUnit-1.2.5.1/html/HUnit.haddock
+haddock-html: /usr/local/share/doc/hs-HUnit-1.2.5.1/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
